@@ -274,10 +274,10 @@ impl Scanner {
         };
         let unclean_digest = digest
             .as_ref()
-            .map(|digest| !is_digest_clean(&self.db, &pkg_name, &pkg_version, &digest))
+            .map(|digest| !is_digest_clean(&self.db, &pkg_name, pkg_version, digest))
             .unwrap_or(false);
         let verification_result = if let Some(digest) = digest.as_ref() {
-            crev_lib::verify_package_digest(&digest, &self.trust_set, &self.requirements, &self.db)
+            crev_lib::verify_package_digest(digest, &self.trust_set, &self.requirements, &self.db)
         } else {
             VerificationStatus::Local
         };
@@ -290,7 +290,7 @@ impl Scanner {
             .get_package_reviews_for_package(
                 PROJECT_SOURCE_CRATES_IO,
                 Some(&pkg_name),
-                Some(&info.id.version()),
+                Some(info.id.version()),
             )
             .collect();
 
@@ -304,7 +304,7 @@ impl Scanner {
         };
 
         let crates_io = self.crates_io()?;
-        let downloads = if required_details.downloads { crates_io.get_downloads_count(&pkg_name, &pkg_version).ok() } else { None };
+        let downloads = if required_details.downloads { crates_io.get_downloads_count(&pkg_name, pkg_version).ok() } else { None };
 
         let owner_list = if required_details.owners { crates_io.get_owners(&pkg_name).ok() } else { None };
         let known_owners = owner_list.as_ref().map(|owner_list| {
@@ -322,7 +322,7 @@ impl Scanner {
         let issues_from_trusted = self.db.get_open_issues_for_version(
             PROJECT_SOURCE_CRATES_IO,
             &pkg_name,
-            &pkg_version,
+            pkg_version,
             &self.trust_set,
             self.requirements.trust_level.into(),
         );
@@ -330,7 +330,7 @@ impl Scanner {
         let issues_from_all = self.db.get_open_issues_for_version(
             PROJECT_SOURCE_CRATES_IO,
             &pkg_name,
-            &pkg_version,
+            pkg_version,
             &self.trust_set,
             crev_data::Level::None.into(),
         );
