@@ -5,7 +5,6 @@
     feature = "documentation",
     doc = "See [user documentation module](./doc/user/index.html)."
 )]
-#![cfg_attr(feature = "documentation", feature(external_doc))]
 use crate::prelude::*;
 use crev_data::{proof::ContentExt, UnlockedId};
 use crev_lib::id::LockedId;
@@ -400,7 +399,7 @@ fn run_command(command: opts::Command) -> Result<CommandExitStatus> {
 
             // Fetch the URLs
             for url in &urls {
-                local.fetch_url_into(&url, &mut db)?;
+                local.fetch_url_into(url, &mut db)?;
             }
 
             // Make reverse lookup for Ids based on their URLs
@@ -598,9 +597,9 @@ fn run_command(command: opts::Command) -> Result<CommandExitStatus> {
                             if args.reset_date {
                                 content.set_date(&now);
                             }
-                            content.set_author(&id.as_public_id());
+                            content.set_author(id.as_public_id());
                             let proof = content.sign_by(&id)?;
-                            maybe_store(&local, &proof, &commit_msg, &args.common)?;
+                            maybe_store(&local, &proof, commit_msg, &args.common)?;
                         }
                         Err(e) => {
                             eprintln!("Ignoried unknwon proof - {}", e);
@@ -646,7 +645,7 @@ fn validate_public_repo_url(url: &str) -> Result<()> {
 fn current_id_set_url(url: &str, use_https_push: bool) -> Result<(), crev_lib::Error> {
     let local = Local::auto_open()?;
     let mut locked_id = local.read_current_locked_id()?;
-    let pub_id = locked_id.to_public_id().id.clone();
+    let pub_id = locked_id.to_public_id().id;
     local.change_locked_id_url(&mut locked_id, url, use_https_push)?;
     local.save_current_id(&pub_id)?;
     local.fetch_trusted(opts::TrustDistanceParams::default().into(), None)?;
@@ -681,12 +680,12 @@ fn generate_new_id_interactively(url: Option<&str>, use_https_push: bool) -> Res
             if let Some(url) = url {
                 validate_public_repo_url(url)?;
 
-                let reusable_ids = existing
+                let reusable_id = existing
                     .iter()
                     .filter(|id| id.url.is_none())
                     .filter_map(|id| local.read_locked_id(&id.id).ok())
-                    .filter(|id| id.has_no_passphrase());
-                for mut locked_id in reusable_ids {
+                    .find(|id| id.has_no_passphrase());
+                if let Some(mut locked_id) = reusable_id {
                     let id = locked_id.to_public_id().id;
                     eprintln!(
                         "Instead of setting up a new CrevID we'll reconfigure the existing one {}",
@@ -809,7 +808,7 @@ fn ensure_crev_id_exists_or_make_one() -> Result<Local> {
 fn ids_from_string(id_strings: &[String]) -> Result<Vec<Id>> {
     id_strings
         .iter()
-        .map(|s| match Id::crevid_from_str(&s) {
+        .map(|s| match Id::crevid_from_str(s) {
             Ok(s) => Ok(s),
             Err(e) => bail!("'{}' is not a valid crev Id: {}", s, e),
         })
@@ -833,7 +832,6 @@ fn print_crev_proof_repo_fork_help() {
     eprintln!(
         "To create your proof repository, fork the template:\n\
     https://github.com/crev-dev/crev-proofs/fork\n\n\
-
     For help visit: https://github.com/crev-dev/crev/wiki/Proof-Repository\n"
     );
 }
@@ -860,7 +858,7 @@ fn change_passphrase(
     unlocked_id: &UnlockedId,
     passphrase: &str,
 ) -> Result<LockedId> {
-    let locked_id = LockedId::from_unlocked_id(&unlocked_id, passphrase)?;
+    let locked_id = LockedId::from_unlocked_id(unlocked_id, passphrase)?;
 
     local.save_locked_id(&locked_id)?;
     local.save_current_id(unlocked_id.as_ref())?;
